import { useState } from "react";
import {
  Table,
  TableBody,
  TableCell,
  TableHead,
  TableHeader,
  TableRow,
} from "@/components/ui/table";
import { Movie, Series, Channel, Match } from "@shared/schema";
import { formatDistanceToNow } from "date-fns";
import { Button } from "@/components/ui/button";
import { StatusBadge } from "@/components/ui/status-badge";
import { ContentTypeBadge } from "@/components/ui/status-badge";

export type ContentItem = Movie | Series | Channel | Match;

interface ContentTableProps {
  items: ContentItem[];
  onEdit: (item: ContentItem) => void;
  onDelete: (item: ContentItem) => void;
}

export function ContentTable({ items, onEdit, onDelete }: ContentTableProps) {
  const getContentType = (item: ContentItem): 'movie' | 'series' | 'channel' | 'match' => {
    if ('year' in item) return 'movie';
    if ('startYear' in item) return 'series';
    if ('streamingUrl' in item && 'sport' in item) return 'match';
    return 'channel';
  };

  const getTitle = (item: ContentItem): string => {
    if ('title' in item) return item.title;
    if ('name' in item) return item.name;
    return 'Unknown';
  };

  const getGenre = (item: ContentItem): string => {
    if ('genre' in item && item.genre) return item.genre;
    if ('type' in item && item.type) return item.type;
    if ('sport' in item && item.sport) return item.sport;
    return '';
  };

  const getStatus = (item: ContentItem): string => {
    if ('status' in item) return item.status || 'active';
    return 'active';
  };

  const getTimeAgo = (item: ContentItem): string => {
    if ('createdAt' in item && item.createdAt) {
      return formatDistanceToNow(new Date(item.createdAt), { addSuffix: true });
    }
    return '';
  };

  return (
    <div className="overflow-x-auto bg-white rounded-lg shadow-sm">
      <div className="px-6 py-4 border-b border-gray-200 flex justify-between items-center">
        <h2 className="font-bold text-gray-800">Recently Added Content</h2>
        <Button variant="ghost" className="text-sm text-primary hover:text-primary-dark">
          View All
        </Button>
      </div>
      <Table>
        <TableHeader>
          <TableRow>
            <TableHead className="px-6 py-3">Title</TableHead>
            <TableHead className="px-6 py-3">Type</TableHead>
            <TableHead className="px-6 py-3">Status</TableHead>
            <TableHead className="px-6 py-3">Added</TableHead>
            <TableHead className="px-6 py-3">Actions</TableHead>
          </TableRow>
        </TableHeader>
        <TableBody>
          {items.map((item) => (
            <TableRow key={item.id}>
              <TableCell className="px-6 py-4">
                <div className="flex items-center">
                  <div className="h-10 w-10 flex-shrink-0 bg-gray-300 rounded"></div>
                  <div className="ml-4">
                    <div className="text-sm font-medium text-gray-900">{getTitle(item)}</div>
                    <div className="text-xs text-gray-500">{getGenre(item)}</div>
                  </div>
                </div>
              </TableCell>
              <TableCell className="px-6 py-4">
                <ContentTypeBadge type={getContentType(item)} />
              </TableCell>
              <TableCell className="px-6 py-4">
                <StatusBadge status={getStatus(item) as any} />
              </TableCell>
              <TableCell className="px-6 py-4 text-sm text-gray-500">
                {getTimeAgo(item)}
              </TableCell>
              <TableCell className="px-6 py-4 text-sm">
                <div className="flex space-x-2">
                  <Button 
                    variant="ghost" 
                    size="icon" 
                    className="text-gray-500 hover:text-primary"
                    onClick={() => onEdit(item)}
                  >
                    <i className="fas fa-edit"></i>
                  </Button>
                  <Button 
                    variant="ghost" 
                    size="icon" 
                    className="text-gray-500 hover:text-red-500"
                    onClick={() => onDelete(item)}
                  >
                    <i className="fas fa-trash"></i>
                  </Button>
                </div>
              </TableCell>
            </TableRow>
          ))}
          {items.length === 0 && (
            <TableRow>
              <TableCell colSpan={5} className="text-center py-4 text-gray-500">
                No content available
              </TableCell>
            </TableRow>
          )}
        </TableBody>
      </Table>
    </div>
  );
}
