import { useState } from "react";
import { Dialog, DialogContent, DialogDescription, DialogFooter, DialogHeader, DialogTitle } from "@/components/ui/dialog";
import { Button } from "@/components/ui/button";
import { Form, FormControl, FormDescription, FormField, FormItem, FormLabel, FormMessage } from "@/components/ui/form";
import { Input } from "@/components/ui/input";
import { useToast } from "@/hooks/use-toast";
import { useForm } from "react-hook-form";
import { zodResolver } from "@hookform/resolvers/zod";
import { z } from "zod";
import { useQueryClient, useMutation } from "@tanstack/react-query";
import { apiRequest } from "@/lib/queryClient";
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from "@/components/ui/select";
import { Tabs, TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs";
import { Card, CardContent, CardDescription, CardFooter, CardHeader, CardTitle } from "@/components/ui/card";
import { Checkbox } from "@/components/ui/checkbox";
import { Switch } from "@/components/ui/switch";
import { Loader2 } from "lucide-react";

// Schema for the match fetcher form
const fetcherSchema = z.object({
  source: z.string().min(1, { message: "Source is required" }),
  sport: z.string().min(1, { message: "Sport is required" }),
  date: z.string().optional(),
  competition: z.string().optional(),
  limit: z.coerce.number().min(1).max(50).default(10),
  autoImport: z.boolean().default(true),
});

type FetcherFormValues = z.infer<typeof fetcherSchema>;

// Mock data for available sources
const availableSources = [
  { id: "sportapi", name: "SportAPI", icon: "globe", sports: ["football", "basketball", "tennis"] },
  { id: "livescore", name: "LiveScore", icon: "futbol", sports: ["football", "hockey", "cricket", "tennis"] },
  { id: "espn", name: "ESPN", icon: "broadcast-tower", sports: ["football", "basketball", "baseball", "hockey"] },
];

interface MatchFetcherModalProps {
  open: boolean;
  onOpenChange: (open: boolean) => void;
}

export function MatchFetcherModal({ open, onOpenChange }: MatchFetcherModalProps) {
  const { toast } = useToast();
  const queryClient = useQueryClient();
  const [activeTab, setActiveTab] = useState("config");
  const [fetchedMatches, setFetchedMatches] = useState<any[]>([]);
  const [selectedMatches, setSelectedMatches] = useState<number[]>([]);
  const [isFetching, setIsFetching] = useState(false);
  const [isImporting, setIsImporting] = useState(false);
  
  const form = useForm<FetcherFormValues>({
    resolver: zodResolver(fetcherSchema),
    defaultValues: {
      source: "",
      sport: "",
      date: new Date().toISOString().split('T')[0], // Today's date
      competition: "all", // Default to "all" instead of empty string
      limit: 10,
      autoImport: true,
    },
  });

  // Available competitions based on selected source and sport
  const getAvailableCompetitions = () => {
    const source = form.watch("source");
    const sport = form.watch("sport");
    
    if (!source || !sport) return [];
    
    // Mock competitions for different sports
    const competitions: Record<string, string[]> = {
      football: ["UEFA Champions League", "Premier League", "La Liga", "Serie A", "Bundesliga"],
      basketball: ["NBA", "Euroleague", "NCAA"],
      tennis: ["ATP Tour", "WTA Tour", "Grand Slam"],
      hockey: ["NHL", "KHL"],
      cricket: ["IPL", "World Cup"],
      baseball: ["MLB", "NPB"],
    };
    
    return competitions[sport] || [];
  };

  // Fetch matches mutation
  const fetchMatchesMutation = useMutation({
    mutationFn: async (data: FetcherFormValues) => {
      setIsFetching(true);
      const res = await apiRequest("POST", "/api/fetch-matches", data);
      return await res.json();
    },
    onSuccess: (data) => {
      setIsFetching(false);
      setFetchedMatches(data.matches || []);
      if (form.getValues("autoImport")) {
        setSelectedMatches(data.matches.map((match: any) => match.id));
      } else {
        setSelectedMatches([]);
      }
      setActiveTab("results");
      toast({
        title: "Matches fetched successfully",
        description: `Found ${data.matches.length} matches from ${form.getValues("source")}`,
      });
    },
    onError: (error) => {
      setIsFetching(false);
      toast({
        title: "Failed to fetch matches",
        description: error instanceof Error ? error.message : "An error occurred",
        variant: "destructive",
      });
    },
  });

  // Import matches mutation
  const importMatchesMutation = useMutation({
    mutationFn: async (matches: any[]) => {
      setIsImporting(true);
      const res = await apiRequest("POST", "/api/import-matches", { matches });
      return await res.json();
    },
    onSuccess: (data) => {
      setIsImporting(false);
      queryClient.invalidateQueries({ queryKey: ['/api/matches'] });
      toast({
        title: "Matches imported successfully",
        description: `Imported ${data.matches.length} matches to your collection`,
      });
      onOpenChange(false);
    },
    onError: (error) => {
      setIsImporting(false);
      toast({
        title: "Failed to import matches",
        description: error instanceof Error ? error.message : "An error occurred",
        variant: "destructive",
      });
    },
  });

  const onSubmit = (data: FetcherFormValues) => {
    fetchMatchesMutation.mutate(data);
  };

  const handleToggleMatch = (id: number) => {
    setSelectedMatches(prev => 
      prev.includes(id) 
        ? prev.filter(matchId => matchId !== id)
        : [...prev, id]
    );
  };

  const handleSelectAll = () => {
    if (selectedMatches.length === fetchedMatches.length) {
      setSelectedMatches([]);
    } else {
      setSelectedMatches(fetchedMatches.map(match => match.id));
    }
  };

  const handleImport = () => {
    const matchesToImport = fetchedMatches.filter(match => 
      selectedMatches.includes(match.id)
    );
    importMatchesMutation.mutate(matchesToImport);
  };

  return (
    <Dialog open={open} onOpenChange={onOpenChange}>
      <DialogContent className="sm:max-w-[650px] max-h-[90vh] overflow-y-auto">
        <DialogHeader>
          <DialogTitle>Match Fetcher</DialogTitle>
          <DialogDescription>
            Fetch matches from external sources and import them to your collection.
          </DialogDescription>
        </DialogHeader>

        <Tabs value={activeTab} onValueChange={setActiveTab} className="w-full">
          <TabsList className="grid w-full grid-cols-2 mb-4">
            <TabsTrigger value="config">Configuration</TabsTrigger>
            <TabsTrigger value="results" disabled={fetchedMatches.length === 0}>
              Results ({fetchedMatches.length})
            </TabsTrigger>
          </TabsList>
          
          <TabsContent value="config">
            <Form {...form}>
              <form onSubmit={form.handleSubmit(onSubmit)} className="space-y-6">
                <div className="grid grid-cols-1 gap-6">
                  <FormField
                    control={form.control}
                    name="source"
                    render={({ field }) => (
                      <FormItem>
                        <FormLabel>Data Source</FormLabel>
                        <div className="grid grid-cols-1 sm:grid-cols-3 gap-3">
                          {availableSources.map(source => (
                            <Card 
                              key={source.id}
                              className={`cursor-pointer border transition-all hover:shadow-md ${field.value === source.id ? 'border-primary ring-1 ring-primary' : ''}`}
                              onClick={() => form.setValue('source', source.id)}
                            >
                              <CardHeader className="py-3 px-4">
                                <div className="flex items-center space-x-2">
                                  <i className={`fas fa-${source.icon} text-primary`}></i>
                                  <CardTitle className="text-base">{source.name}</CardTitle>
                                </div>
                              </CardHeader>
                            </Card>
                          ))}
                        </div>
                        <FormMessage />
                      </FormItem>
                    )}
                  />

                  <div className="grid grid-cols-1 sm:grid-cols-2 gap-4">
                    <FormField
                      control={form.control}
                      name="sport"
                      render={({ field }) => (
                        <FormItem>
                          <FormLabel>Sport</FormLabel>
                          <Select
                            disabled={!form.watch("source")}
                            onValueChange={field.onChange}
                            value={field.value}
                          >
                            <FormControl>
                              <SelectTrigger>
                                <SelectValue placeholder="Select sport" />
                              </SelectTrigger>
                            </FormControl>
                            <SelectContent>
                              {form.watch("source") && 
                                availableSources
                                  .find(s => s.id === form.watch("source"))
                                  ?.sports.map(sport => (
                                    <SelectItem key={sport} value={sport}>
                                      {sport.charAt(0).toUpperCase() + sport.slice(1)}
                                    </SelectItem>
                                  ))
                              }
                            </SelectContent>
                          </Select>
                          <FormMessage />
                        </FormItem>
                      )}
                    />

                    <FormField
                      control={form.control}
                      name="competition"
                      render={({ field }) => (
                        <FormItem>
                          <FormLabel>Competition (Optional)</FormLabel>
                          <Select
                            disabled={!form.watch("sport")}
                            onValueChange={field.onChange}
                            value={field.value || "all"}
                          >
                            <FormControl>
                              <SelectTrigger>
                                <SelectValue placeholder="Any competition" />
                              </SelectTrigger>
                            </FormControl>
                            <SelectContent>
                              <SelectItem value="all">Any competition</SelectItem>
                              {getAvailableCompetitions().map(comp => (
                                <SelectItem key={comp} value={comp}>{comp}</SelectItem>
                              ))}
                            </SelectContent>
                          </Select>
                          <FormMessage />
                        </FormItem>
                      )}
                    />
                  </div>

                  <div className="grid grid-cols-1 sm:grid-cols-2 gap-4">
                    <FormField
                      control={form.control}
                      name="date"
                      render={({ field }) => (
                        <FormItem>
                          <FormLabel>Date (Optional)</FormLabel>
                          <FormControl>
                            <Input type="date" {...field} />
                          </FormControl>
                          <FormMessage />
                        </FormItem>
                      )}
                    />

                    <FormField
                      control={form.control}
                      name="limit"
                      render={({ field }) => (
                        <FormItem>
                          <FormLabel>Maximum Results</FormLabel>
                          <FormControl>
                            <Input type="number" min="1" max="50" {...field} />
                          </FormControl>
                          <FormMessage />
                        </FormItem>
                      )}
                    />
                  </div>

                  <FormField
                    control={form.control}
                    name="autoImport"
                    render={({ field }) => (
                      <FormItem className="flex flex-row items-center justify-between rounded-lg border p-3 shadow-sm">
                        <div className="space-y-0.5">
                          <FormLabel>Auto-select matches for import</FormLabel>
                          <FormDescription>
                            Automatically select all fetched matches for import
                          </FormDescription>
                        </div>
                        <FormControl>
                          <Switch
                            checked={field.value}
                            onCheckedChange={field.onChange}
                          />
                        </FormControl>
                      </FormItem>
                    )}
                  />
                </div>

                <DialogFooter>
                  <Button 
                    type="submit" 
                    className="w-full"
                    disabled={isFetching || !form.formState.isValid}
                  >
                    {isFetching ? (
                      <>
                        <Loader2 className="mr-2 h-4 w-4 animate-spin" />
                        Fetching matches...
                      </>
                    ) : (
                      'Fetch Matches'
                    )}
                  </Button>
                </DialogFooter>
              </form>
            </Form>
          </TabsContent>
          
          <TabsContent value="results">
            {fetchedMatches.length > 0 ? (
              <>
                <div className="flex items-center justify-between mb-4">
                  <div className="text-sm text-gray-500">
                    {selectedMatches.length} of {fetchedMatches.length} matches selected
                  </div>
                  <Button 
                    variant="outline" 
                    size="sm" 
                    onClick={handleSelectAll}
                  >
                    {selectedMatches.length === fetchedMatches.length ? "Deselect All" : "Select All"}
                  </Button>
                </div>
                
                <div className="border rounded-md overflow-hidden mb-6">
                  <table className="w-full">
                    <thead className="bg-muted/50">
                      <tr>
                        <th className="px-4 py-3 text-left text-xs font-medium text-muted-foreground uppercase tracking-wider w-[40px]">
                          <span className="sr-only">Select</span>
                        </th>
                        <th className="px-4 py-3 text-left text-xs font-medium text-muted-foreground uppercase tracking-wider">
                          Match
                        </th>
                        <th className="px-4 py-3 text-left text-xs font-medium text-muted-foreground uppercase tracking-wider">
                          Competition
                        </th>
                        <th className="px-4 py-3 text-left text-xs font-medium text-muted-foreground uppercase tracking-wider hidden md:table-cell">
                          Date & Time
                        </th>
                      </tr>
                    </thead>
                    <tbody className="divide-y divide-muted/30">
                      {fetchedMatches.map(match => (
                        <tr 
                          key={match.id} 
                          className={`hover:bg-muted/30 cursor-pointer ${selectedMatches.includes(match.id) ? 'bg-primary/5' : ''}`}
                          onClick={() => handleToggleMatch(match.id)}
                        >
                          <td className="px-4 py-3 whitespace-nowrap">
                            <Checkbox
                              checked={selectedMatches.includes(match.id)}
                              onCheckedChange={() => handleToggleMatch(match.id)}
                              onClick={(e) => e.stopPropagation()}
                            />
                          </td>
                          <td className="px-4 py-3 text-sm">
                            <div className="font-medium">{match.title}</div>
                            <div className="text-muted-foreground text-xs">
                              {match.teamHome} vs {match.teamAway}
                            </div>
                          </td>
                          <td className="px-4 py-3 text-sm">
                            {match.competition}
                          </td>
                          <td className="px-4 py-3 text-sm hidden md:table-cell">
                            {new Date(match.startTime).toLocaleString()}
                          </td>
                        </tr>
                      ))}
                    </tbody>
                  </table>
                </div>
                
                <DialogFooter>
                  <Button
                    variant="secondary"
                    onClick={() => setActiveTab("config")}
                    className="mr-2"
                  >
                    Back to Search
                  </Button>
                  <Button
                    onClick={handleImport}
                    disabled={isImporting || selectedMatches.length === 0}
                  >
                    {isImporting ? (
                      <>
                        <Loader2 className="mr-2 h-4 w-4 animate-spin" />
                        Importing...
                      </>
                    ) : (
                      `Import ${selectedMatches.length} Match${selectedMatches.length !== 1 ? 'es' : ''}`
                    )}
                  </Button>
                </DialogFooter>
              </>
            ) : (
              <div className="text-center py-8">
                <p className="text-muted-foreground">No matches found. Try a different search.</p>
                <Button
                  variant="outline"
                  onClick={() => setActiveTab("config")}
                  className="mt-4"
                >
                  Back to Search
                </Button>
              </div>
            )}
          </TabsContent>
        </Tabs>
      </DialogContent>
    </Dialog>
  );
}