import { useState } from "react";
import { DashboardLayout } from "@/components/dashboard/layout";
import { Button } from "@/components/ui/button";
import { Input } from "@/components/ui/input";
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from "@/components/ui/select";
import { AddMovieModal } from "@/components/modals/add-movie-modal";
import { useQuery, useMutation, useQueryClient } from "@tanstack/react-query";
import { useToast } from "@/hooks/use-toast";
import { apiRequest } from "@/lib/queryClient";
import { Movie } from "@shared/schema";
import {
  Table,
  TableBody,
  TableCell,
  TableHead,
  TableHeader,
  TableRow,
} from "@/components/ui/table";
import { StatusBadge } from "@/components/ui/status-badge";
import { Loader2 } from "lucide-react";
import { AlertDialog, AlertDialogAction, AlertDialogCancel, AlertDialogContent, AlertDialogDescription, AlertDialogFooter, AlertDialogHeader, AlertDialogTitle } from "@/components/ui/alert-dialog";
import { format } from "date-fns";

export default function MoviesPage() {
  const { toast } = useToast();
  const queryClient = useQueryClient();
  const [searchQuery, setSearchQuery] = useState("");
  const [genreFilter, setGenreFilter] = useState("all");
  const [showAddModal, setShowAddModal] = useState(false);
  const [movieToDelete, setMovieToDelete] = useState<Movie | null>(null);

  const { data: movies = [], isLoading } = useQuery({
    queryKey: ['/api/movies'],
  });

  const deleteMovieMutation = useMutation({
    mutationFn: async (id: number) => {
      await apiRequest("DELETE", `/api/movies/${id}`);
      return id;
    },
    onSuccess: () => {
      queryClient.invalidateQueries({ queryKey: ['/api/movies'] });
      queryClient.invalidateQueries({ queryKey: ['/api/recent-content'] });
      queryClient.invalidateQueries({ queryKey: ['/api/stats'] });
      toast({
        title: "Movie deleted",
        description: "The movie has been successfully deleted.",
      });
    },
    onError: (error) => {
      toast({
        title: "Failed to delete movie",
        description: error.message || "An error occurred while deleting the movie.",
        variant: "destructive",
      });
    },
  });

  const filteredMovies = movies.filter(movie => {
    const matchesSearch = movie.title?.toLowerCase().includes(searchQuery.toLowerCase());
    const matchesGenre = genreFilter === 'all' || movie.genre === genreFilter;
    return matchesSearch && matchesGenre;
  });

  const uniqueGenres = Array.from(new Set(movies.map(movie => movie.genre).filter(Boolean)));

  const handleDeleteMovie = (movie: Movie) => {
    setMovieToDelete(movie);
  };

  const confirmDelete = () => {
    if (movieToDelete) {
      deleteMovieMutation.mutate(movieToDelete.id);
      setMovieToDelete(null);
    }
  };

  return (
    <DashboardLayout
      title="Movies"
      subtitle="Manage your movie collection"
    >
      <div className="mb-6 flex flex-col md:flex-row gap-4 justify-between">
        <div className="flex flex-col md:flex-row gap-4 md:items-center">
          <Input
            placeholder="Search movies..."
            className="max-w-sm"
            value={searchQuery}
            onChange={(e) => setSearchQuery(e.target.value)}
          />
          <Select value={genreFilter} onValueChange={setGenreFilter}>
            <SelectTrigger className="max-w-[200px]">
              <SelectValue placeholder="All Genres" />
            </SelectTrigger>
            <SelectContent>
              <SelectItem value="all">All Genres</SelectItem>
              {uniqueGenres.map(genre => (
                <SelectItem key={genre} value={genre as string}>{genre}</SelectItem>
              ))}
            </SelectContent>
          </Select>
        </div>
        <Button onClick={() => setShowAddModal(true)}>
          <i className="fas fa-plus mr-2"></i> Add Movie
        </Button>
      </div>

      <div className="bg-white rounded-lg shadow-sm overflow-hidden">
        {isLoading ? (
          <div className="flex justify-center items-center p-12">
            <Loader2 className="h-8 w-8 animate-spin text-primary" />
          </div>
        ) : filteredMovies.length === 0 ? (
          <div className="flex flex-col items-center justify-center p-12 text-center">
            <i className="fas fa-film text-gray-300 text-5xl mb-4"></i>
            <h3 className="text-lg font-medium text-gray-900 mb-1">No movies found</h3>
            <p className="text-gray-500 mb-4">
              {searchQuery || genreFilter !== 'all'
                ? "Try adjusting your search or filter criteria"
                : "Start adding movies to your collection"}
            </p>
            {!(searchQuery || genreFilter !== 'all') && (
              <Button onClick={() => setShowAddModal(true)}>
                <i className="fas fa-plus mr-2"></i> Add Your First Movie
              </Button>
            )}
          </div>
        ) : (
          <Table>
            <TableHeader>
              <TableRow>
                <TableHead>Title</TableHead>
                <TableHead>Year</TableHead>
                <TableHead>Genre</TableHead>
                <TableHead>Duration</TableHead>
                <TableHead>Status</TableHead>
                <TableHead>Added On</TableHead>
                <TableHead className="text-right">Actions</TableHead>
              </TableRow>
            </TableHeader>
            <TableBody>
              {filteredMovies.map((movie) => (
                <TableRow key={movie.id}>
                  <TableCell className="font-medium">
                    <div className="flex items-center">
                      {movie.poster ? (
                        <div
                          className="h-10 w-10 rounded bg-cover bg-center mr-3"
                          style={{ backgroundImage: `url(${movie.poster})` }}
                        ></div>
                      ) : (
                        <div className="h-10 w-10 rounded bg-gray-200 flex items-center justify-center mr-3">
                          <i className="fas fa-film text-gray-400"></i>
                        </div>
                      )}
                      {movie.title}
                    </div>
                  </TableCell>
                  <TableCell>{movie.year || "N/A"}</TableCell>
                  <TableCell>{movie.genre || "N/A"}</TableCell>
                  <TableCell>{movie.runtime ? `${movie.runtime} min` : "N/A"}</TableCell>
                  <TableCell>
                    <StatusBadge status={(movie.status as any) || "active"} />
                  </TableCell>
                  <TableCell>
                    {movie.createdAt ? format(new Date(movie.createdAt), 'MMM d, yyyy') : "N/A"}
                  </TableCell>
                  <TableCell className="text-right">
                    <div className="flex justify-end space-x-2">
                      <Button variant="ghost" size="icon" title="Edit">
                        <i className="fas fa-edit text-gray-500 hover:text-primary"></i>
                      </Button>
                      <Button 
                        variant="ghost" 
                        size="icon" 
                        title="Delete" 
                        onClick={() => handleDeleteMovie(movie)}
                      >
                        <i className="fas fa-trash text-gray-500 hover:text-red-500"></i>
                      </Button>
                    </div>
                  </TableCell>
                </TableRow>
              ))}
            </TableBody>
          </Table>
        )}
      </div>

      <AddMovieModal
        open={showAddModal}
        onOpenChange={setShowAddModal}
      />

      <AlertDialog open={!!movieToDelete} onOpenChange={() => setMovieToDelete(null)}>
        <AlertDialogContent>
          <AlertDialogHeader>
            <AlertDialogTitle>Are you sure?</AlertDialogTitle>
            <AlertDialogDescription>
              This action cannot be undone. This will permanently delete
              the movie "{movieToDelete?.title}" from your collection.
            </AlertDialogDescription>
          </AlertDialogHeader>
          <AlertDialogFooter>
            <AlertDialogCancel>Cancel</AlertDialogCancel>
            <AlertDialogAction onClick={confirmDelete} className="bg-red-500 hover:bg-red-600">
              {deleteMovieMutation.isPending ? "Deleting..." : "Delete"}
            </AlertDialogAction>
          </AlertDialogFooter>
        </AlertDialogContent>
      </AlertDialog>
    </DashboardLayout>
  );
}
