import { useState } from "react";
import { DashboardLayout } from "@/components/dashboard/layout";
import { Button } from "@/components/ui/button";
import { Input } from "@/components/ui/input";
import { Textarea } from "@/components/ui/textarea";
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from "@/components/ui/select";
import { Checkbox } from "@/components/ui/checkbox";
import { Card, CardContent, CardDescription, CardFooter, CardHeader, CardTitle } from "@/components/ui/card";
import { Form, FormControl, FormDescription, FormField, FormItem, FormLabel, FormMessage } from "@/components/ui/form";
import { Tabs, TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs";
import { FileUpload } from "@/components/ui/file-upload";
import { useQuery, useMutation, useQueryClient } from "@tanstack/react-query";
import { useToast } from "@/hooks/use-toast";
import { apiRequest } from "@/lib/queryClient";
import { Notification, InsertNotification, Movie, Series, Channel, Match } from "@shared/schema";
import { Loader2, BellPlus } from "lucide-react";
import { format } from "date-fns";
import { AlertDialog, AlertDialogAction, AlertDialogCancel, AlertDialogContent, AlertDialogDescription, AlertDialogFooter, AlertDialogHeader, AlertDialogTitle } from "@/components/ui/alert-dialog";
import { useForm } from "react-hook-form";
import { zodResolver } from "@hookform/resolvers/zod";
import { z } from "zod";

// Define notification form schema
const NotificationFormSchema = z.object({
  title: z.string().min(1, "Title is required"),
  message: z.string().min(1, "Message is required"),
  type: z.string().default("info"),
  image: z.any().optional(),
  link: z.string().optional(),
  contentId: z.number().optional(),
  contentType: z.string().optional(),
});

type NotificationFormValues = z.infer<typeof NotificationFormSchema>;

export default function NotificationsPage() {
  const { toast } = useToast();
  const queryClient = useQueryClient();
  const [searchQuery, setSearchQuery] = useState("");
  const [typeFilter, setTypeFilter] = useState("all");
  const [selectedNotifications, setSelectedNotifications] = useState<number[]>([]);
  const [showCreateForm, setShowCreateForm] = useState(false);
  
  // Create form with validation
  const form = useForm<NotificationFormValues>({
    resolver: zodResolver(NotificationFormSchema),
    defaultValues: {
      title: "",
      message: "",
      type: "info",
      link: "",
      contentType: "none",
    },
  });
  
  // Fetch content for linking
  const { data: movies = [] } = useQuery<Movie[]>({
    queryKey: ['/api/movies'],
    enabled: showCreateForm,
  });
  
  const { data: seriesList = [] } = useQuery<Series[]>({
    queryKey: ['/api/series'],
    enabled: showCreateForm,
  });
  
  const { data: channels = [] } = useQuery<Channel[]>({
    queryKey: ['/api/channels'],
    enabled: showCreateForm,
  });
  
  const { data: matches = [] } = useQuery<Match[]>({
    queryKey: ['/api/matches'],
    enabled: showCreateForm,
  });
  
  // Create notification mutation
  const createNotificationMutation = useMutation({
    mutationFn: async (data: NotificationFormValues) => {
      const notificationData: InsertNotification = {
        title: data.title,
        message: data.message,
        type: data.type,
      };
      
      // Add optional fields if they exist
      if (data.link) notificationData.link = data.link;
      
      // Only add content references if a valid content type and ID are selected
      if (data.contentType && data.contentType !== 'none' && data.contentId) {
        notificationData.contentType = data.contentType;
        notificationData.contentId = data.contentId;
      }
      
      // If image is a File object, we'd need to handle image upload here
      // and then set the URL in the notification data
      
      const res = await apiRequest("POST", "/api/notifications", notificationData);
      return res.json();
    },
    onSuccess: () => {
      queryClient.invalidateQueries({ queryKey: ['/api/notifications'] });
      setShowCreateForm(false);
      form.reset();
      toast({
        title: "Notification created",
        description: "The notification has been created successfully.",
      });
    },
    onError: (error) => {
      toast({
        title: "Failed to create notification",
        description: error.message || "An error occurred.",
        variant: "destructive",
      });
    },
  });

  const { data: notifications = [], isLoading } = useQuery({
    queryKey: ['/api/notifications'],
  });

  const markAsReadMutation = useMutation({
    mutationFn: async (id: number) => {
      await apiRequest("PATCH", `/api/notifications/${id}/read`);
      return id;
    },
    onSuccess: () => {
      queryClient.invalidateQueries({ queryKey: ['/api/notifications'] });
    },
    onError: (error) => {
      toast({
        title: "Failed to mark notification as read",
        description: error.message || "An error occurred.",
        variant: "destructive",
      });
    },
  });

  const deleteNotificationMutation = useMutation({
    mutationFn: async (id: number) => {
      await apiRequest("DELETE", `/api/notifications/${id}`);
      return id;
    },
    onSuccess: () => {
      queryClient.invalidateQueries({ queryKey: ['/api/notifications'] });
      toast({
        title: "Notification deleted",
        description: "The notification has been successfully deleted.",
      });
    },
    onError: (error) => {
      toast({
        title: "Failed to delete notification",
        description: error.message || "An error occurred.",
        variant: "destructive",
      });
    },
  });

  const markAllReadMutation = useMutation({
    mutationFn: async () => {
      if (selectedNotifications.length > 0) {
        for (const id of selectedNotifications) {
          await apiRequest("PATCH", `/api/notifications/${id}/read`);
        }
        return selectedNotifications;
      } else {
        for (const notification of filteredNotifications) {
          if (!notification.read) {
            await apiRequest("PATCH", `/api/notifications/${notification.id}/read`);
          }
        }
        return filteredNotifications.map(n => n.id);
      }
    },
    onSuccess: () => {
      queryClient.invalidateQueries({ queryKey: ['/api/notifications'] });
      toast({
        title: "Notifications marked as read",
        description: selectedNotifications.length > 0 
          ? "Selected notifications have been marked as read."
          : "All notifications have been marked as read.",
      });
      setSelectedNotifications([]);
    },
    onError: (error) => {
      toast({
        title: "Failed to mark notifications as read",
        description: error.message || "An error occurred.",
        variant: "destructive",
      });
    },
  });

  const filteredNotifications = notifications.filter(notification => {
    const matchesSearch = notification.title?.toLowerCase().includes(searchQuery.toLowerCase()) ||
                          notification.message?.toLowerCase().includes(searchQuery.toLowerCase());
    const matchesType = typeFilter === 'all' || notification.type === typeFilter;
    return matchesSearch && matchesType;
  });

  const handleCheckbox = (id: number, checked: boolean) => {
    if (checked) {
      setSelectedNotifications(prev => [...prev, id]);
    } else {
      setSelectedNotifications(prev => prev.filter(notifId => notifId !== id));
    }
  };

  const handleMarkRead = (notification: Notification) => {
    if (!notification.read) {
      markAsReadMutation.mutate(notification.id);
    }
  };

  const handleDelete = (id: number) => {
    deleteNotificationMutation.mutate(id);
  };

  const handleMarkAllRead = () => {
    markAllReadMutation.mutate();
  };

  const getNotificationIcon = (type: string) => {
    switch (type) {
      case 'info': return <i className="fas fa-info-circle text-blue-500"></i>;
      case 'warning': return <i className="fas fa-exclamation-triangle text-yellow-500"></i>;
      case 'error': return <i className="fas fa-times-circle text-red-500"></i>;
      case 'success': return <i className="fas fa-check-circle text-green-500"></i>;
      default: return <i className="fas fa-bell text-gray-500"></i>;
    }
  };

  const onSubmit = (values: NotificationFormValues) => {
    createNotificationMutation.mutate(values);
  };

  return (
    <DashboardLayout
      title="Notifications"
      subtitle="View and manage system notifications"
    >
      <div className="mb-6 flex flex-col md:flex-row gap-4 justify-between">
        <div className="flex flex-col md:flex-row gap-4 md:items-center">
          <Input
            placeholder="Search notifications..."
            className="max-w-sm"
            value={searchQuery}
            onChange={(e) => setSearchQuery(e.target.value)}
          />
          <Select value={typeFilter} onValueChange={setTypeFilter}>
            <SelectTrigger className="max-w-[180px]">
              <SelectValue placeholder="All Types" />
            </SelectTrigger>
            <SelectContent>
              <SelectItem value="all">All Types</SelectItem>
              <SelectItem value="info">Info</SelectItem>
              <SelectItem value="warning">Warning</SelectItem>
              <SelectItem value="error">Error</SelectItem>
              <SelectItem value="success">Success</SelectItem>
            </SelectContent>
          </Select>
        </div>
        <div className="flex gap-2">
          <Button 
            variant="outline" 
            onClick={handleMarkAllRead} 
            disabled={markAllReadMutation.isPending || filteredNotifications.length === 0}
          >
            <i className="fas fa-check-double mr-2"></i>
            {selectedNotifications.length > 0 ? "Mark Selected as Read" : "Mark All as Read"}
          </Button>
          <Button 
            variant="outline" 
            onClick={() => setSelectedNotifications([])}
            disabled={selectedNotifications.length === 0}
          >
            <i className="fas fa-times mr-2"></i> Clear Selection
          </Button>
          <Button 
            onClick={() => setShowCreateForm(!showCreateForm)}
          >
            <BellPlus className="mr-2 h-4 w-4" />
            {showCreateForm ? "Cancel" : "Create Notification"}
          </Button>
        </div>
      </div>
      
      {showCreateForm && (
        <Card className="mb-6">
          <CardHeader>
            <CardTitle>Create New Notification</CardTitle>
            <CardDescription>
              Create a new notification to send to users. Notifications can include an optional image and link.
            </CardDescription>
          </CardHeader>
          <CardContent>
            <Form {...form}>
              <form onSubmit={form.handleSubmit(onSubmit)} className="space-y-6">
                <Tabs defaultValue="basic">
                  <TabsList className="mb-4">
                    <TabsTrigger value="basic">Basic Info</TabsTrigger>
                    <TabsTrigger value="content">Content Link</TabsTrigger>
                    <TabsTrigger value="media">Media</TabsTrigger>
                  </TabsList>
                  
                  <TabsContent value="basic" className="space-y-4">
                    <FormField
                      control={form.control}
                      name="title"
                      render={({ field }) => (
                        <FormItem>
                          <FormLabel>Title</FormLabel>
                          <FormControl>
                            <Input placeholder="Notification title" {...field} />
                          </FormControl>
                          <FormMessage />
                        </FormItem>
                      )}
                    />
                    
                    <FormField
                      control={form.control}
                      name="message"
                      render={({ field }) => (
                        <FormItem>
                          <FormLabel>Message</FormLabel>
                          <FormControl>
                            <Textarea 
                              placeholder="Notification message content" 
                              className="min-h-[100px]" 
                              {...field} 
                            />
                          </FormControl>
                          <FormMessage />
                        </FormItem>
                      )}
                    />
                    
                    <FormField
                      control={form.control}
                      name="type"
                      render={({ field }) => (
                        <FormItem>
                          <FormLabel>Type</FormLabel>
                          <Select
                            onValueChange={field.onChange}
                            defaultValue={field.value}
                          >
                            <FormControl>
                              <SelectTrigger>
                                <SelectValue placeholder="Select notification type" />
                              </SelectTrigger>
                            </FormControl>
                            <SelectContent>
                              <SelectItem value="info">Info</SelectItem>
                              <SelectItem value="warning">Warning</SelectItem>
                              <SelectItem value="error">Error</SelectItem>
                              <SelectItem value="success">Success</SelectItem>
                            </SelectContent>
                          </Select>
                          <FormMessage />
                        </FormItem>
                      )}
                    />
                    
                    <FormField
                      control={form.control}
                      name="link"
                      render={({ field }) => (
                        <FormItem>
                          <FormLabel>External Link (Optional)</FormLabel>
                          <FormControl>
                            <Input placeholder="https://example.com" {...field} />
                          </FormControl>
                          <FormDescription>
                            An external URL that users will be directed to when they tap on the notification.
                          </FormDescription>
                          <FormMessage />
                        </FormItem>
                      )}
                    />
                  </TabsContent>
                  
                  <TabsContent value="content" className="space-y-4">
                    <div className="grid grid-cols-1 md:grid-cols-2 gap-4 mb-4">
                      <FormField
                        control={form.control}
                        name="contentType"
                        render={({ field }) => (
                          <FormItem>
                            <FormLabel>Content Type</FormLabel>
                            <Select
                              onValueChange={(value) => {
                                field.onChange(value);
                                if (value === 'none') {
                                  form.setValue('contentId', undefined);
                                }
                              }}
                              value={field.value}
                            >
                              <FormControl>
                                <SelectTrigger>
                                  <SelectValue placeholder="Select content type" />
                                </SelectTrigger>
                              </FormControl>
                              <SelectContent>
                                <SelectItem value="none">None</SelectItem>
                                <SelectItem value="movie">Movie</SelectItem>
                                <SelectItem value="series">Series</SelectItem>
                                <SelectItem value="channel">Channel</SelectItem>
                                <SelectItem value="match">Match</SelectItem>
                              </SelectContent>
                            </Select>
                            <FormDescription>
                              Link this notification to specific content
                            </FormDescription>
                            <FormMessage />
                          </FormItem>
                        )}
                      />
                      
                      {form.watch('contentType') && form.watch('contentType') !== 'none' && (
                        <FormField
                          control={form.control}
                          name="contentId"
                          render={({ field }) => (
                            <FormItem>
                              <FormLabel>Select Content</FormLabel>
                              <Select
                                onValueChange={(value) => field.onChange(parseInt(value))}
                                value={field.value?.toString()}
                              >
                                <FormControl>
                                  <SelectTrigger>
                                    <SelectValue placeholder="Select content" />
                                  </SelectTrigger>
                                </FormControl>
                                <SelectContent>
                                  {form.watch('contentType') === 'movie' && 
                                    movies.map(movie => (
                                      <SelectItem key={movie.id} value={movie.id.toString()}>
                                        {movie.title}
                                      </SelectItem>
                                    ))
                                  }
                                  {form.watch('contentType') === 'series' && 
                                    seriesList.map(series => (
                                      <SelectItem key={series.id} value={series.id.toString()}>
                                        {series.title}
                                      </SelectItem>
                                    ))
                                  }
                                  {form.watch('contentType') === 'channel' && 
                                    channels.map(channel => (
                                      <SelectItem key={channel.id} value={channel.id.toString()}>
                                        {channel.name}
                                      </SelectItem>
                                    ))
                                  }
                                  {form.watch('contentType') === 'match' && 
                                    matches.map(match => (
                                      <SelectItem key={match.id} value={match.id.toString()}>
                                        {match.title}
                                      </SelectItem>
                                    ))
                                  }
                                </SelectContent>
                              </Select>
                              <FormDescription>
                                Choose specific content to link to
                              </FormDescription>
                              <FormMessage />
                            </FormItem>
                          )}
                        />
                      )}
                    </div>
                  </TabsContent>
                  
                  <TabsContent value="media" className="space-y-4">
                    <FormField
                      control={form.control}
                      name="image"
                      render={({ field }) => (
                        <FormItem>
                          <FormLabel>Notification Image (Optional)</FormLabel>
                          <FormControl>
                            <FileUpload
                              id="notification-image"
                              label="Upload Image"
                              accept="image/*"
                              maxSize={5} // 5MB
                              onChange={(file) => field.onChange(file)}
                              error={form.formState.errors.image?.message as string}
                            />
                          </FormControl>
                          <FormDescription>
                            Add an image that will be displayed with the notification. Maximum size: 5MB
                          </FormDescription>
                          <FormMessage />
                        </FormItem>
                      )}
                    />
                  </TabsContent>
                </Tabs>
                
                <div className="flex justify-end gap-2">
                  <Button 
                    type="button" 
                    variant="outline" 
                    onClick={() => setShowCreateForm(false)}
                  >
                    Cancel
                  </Button>
                  <Button 
                    type="submit" 
                    disabled={createNotificationMutation.isPending}
                  >
                    {createNotificationMutation.isPending ? (
                      <>
                        <Loader2 className="mr-2 h-4 w-4 animate-spin" />
                        Creating...
                      </>
                    ) : (
                      'Create Notification'
                    )}
                  </Button>
                </div>
              </form>
            </Form>
          </CardContent>
        </Card>
      )}

      <div className="bg-white rounded-lg shadow-sm">
        {isLoading ? (
          <div className="flex justify-center items-center p-12">
            <Loader2 className="h-8 w-8 animate-spin text-primary" />
          </div>
        ) : filteredNotifications.length === 0 ? (
          <div className="flex flex-col items-center justify-center p-12 text-center">
            <i className="fas fa-bell-slash text-gray-300 text-5xl mb-4"></i>
            <h3 className="text-lg font-medium text-gray-900 mb-1">No notifications found</h3>
            <p className="text-gray-500">
              {searchQuery || typeFilter
                ? "Try adjusting your search or filter criteria"
                : "You don't have any notifications yet"}
            </p>
          </div>
        ) : (
          <div className="divide-y divide-gray-200">
            {filteredNotifications.map((notification) => (
              <div 
                key={notification.id} 
                className={`p-4 hover:bg-gray-50 flex ${notification.read ? 'opacity-70' : ''}`}
              >
                <div className="flex items-start">
                  <Checkbox 
                    checked={selectedNotifications.includes(notification.id)}
                    onCheckedChange={(checked) => handleCheckbox(notification.id, checked as boolean)}
                    className="mr-3 mt-1"
                  />
                </div>
                <div className="flex-shrink-0 pt-0.5 mr-4">
                  <div className={`h-10 w-10 rounded-full flex items-center justify-center bg-${notification.type === 'info' ? 'blue' : notification.type === 'warning' ? 'yellow' : notification.type === 'error' ? 'red' : 'green'}-100`}>
                    {getNotificationIcon(notification.type)}
                  </div>
                </div>
                <div className="flex-1 min-w-0">
                  <div className="flex items-center justify-between">
                    <h4 className="text-sm font-medium text-gray-900">{notification.title}</h4>
                    <span className="text-xs text-gray-500">
                      {format(new Date(notification.createdAt), 'MMM d, yyyy h:mm a')}
                    </span>
                  </div>
                  <p className="text-sm text-gray-500 mt-1">{notification.message}</p>
                  <div className="mt-2 flex justify-between items-center">
                    <div>
                      <span className={`inline-flex items-center px-2.5 py-0.5 rounded-full text-xs font-medium bg-${notification.type === 'info' ? 'blue' : notification.type === 'warning' ? 'yellow' : notification.type === 'error' ? 'red' : 'green'}-100 text-${notification.type === 'info' ? 'blue' : notification.type === 'warning' ? 'yellow' : notification.type === 'error' ? 'red' : 'green'}-800`}>
                        {notification.type}
                      </span>
                      {notification.read && (
                        <span className="ml-2 inline-flex items-center px-2.5 py-0.5 rounded-full text-xs font-medium bg-gray-100 text-gray-800">
                          Read
                        </span>
                      )}
                    </div>
                    <div className="flex gap-2">
                      {!notification.read && (
                        <Button 
                          variant="ghost" 
                          size="sm" 
                          onClick={() => handleMarkRead(notification)}
                        >
                          <i className="fas fa-check text-green-500 mr-1"></i> Mark as Read
                        </Button>
                      )}
                      <Button 
                        variant="ghost" 
                        size="sm" 
                        onClick={() => handleDelete(notification.id)}
                      >
                        <i className="fas fa-trash text-red-500 mr-1"></i> Delete
                      </Button>
                    </div>
                  </div>
                </div>
              </div>
            ))}
          </div>
        )}
      </div>
    </DashboardLayout>
  );
}
