import { useState } from "react";
import { useQuery, useMutation } from "@tanstack/react-query";
import { Button } from "@/components/ui/button";
import { Card, CardContent, CardHeader, CardTitle } from "@/components/ui/card";
import { Tabs, TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs";
import {
  Dialog,
  DialogContent,
  DialogHeader,
  DialogTitle,
  DialogTrigger,
  DialogFooter,
  DialogClose,
} from "@/components/ui/dialog";
import {
  Form,
  FormControl,
  FormField,
  FormItem,
  FormLabel,
  FormMessage,
} from "@/components/ui/form";
import { Input } from "@/components/ui/input";
import { Textarea } from "@/components/ui/textarea";
import { Switch } from "@/components/ui/switch";
import { FileUpload } from "@/components/ui/file-upload";
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from "@/components/ui/select";
import { zodResolver } from "@hookform/resolvers/zod";
import { useForm } from "react-hook-form";
import { z } from "zod";
import { FolderPlus, Edit, Trash2, Filter } from "lucide-react";
import { DashboardLayout } from "@/components/dashboard/layout";
import { useToast } from "@/hooks/use-toast";
import { apiRequest, queryClient } from "@/lib/queryClient";
import { Subcategory, Category, InsertSubcategory } from "@shared/schema";

// Form schema for subcategory
const SubcategoryFormSchema = z.object({
  name: z.string().min(2, {
    message: "Name must be at least 2 characters.",
  }),
  type: z.string({
    required_error: "Please select a type."
  }),
  parentCategoryId: z.coerce.number({
    required_error: "Please select a parent category."
  }),
  description: z.string().nullable().optional(),
  thumbnail: z.string().nullable().optional(),
  banner: z.string().nullable().optional(),
  isActive: z.boolean().default(true),
  displayOrder: z.coerce.number().nullable().optional(),
});

type SubcategoryFormValues = z.infer<typeof SubcategoryFormSchema>;

export default function SubcategoriesPage() {
  const { toast } = useToast();
  const [activeTab, setActiveTab] = useState("all");
  const [selectedParentCategory, setSelectedParentCategory] = useState<string>("all");
  const [isAddDialogOpen, setIsAddDialogOpen] = useState(false);
  const [isEditDialogOpen, setIsEditDialogOpen] = useState(false);
  const [isDeleteDialogOpen, setIsDeleteDialogOpen] = useState(false);
  const [selectedSubcategory, setSelectedSubcategory] = useState<Subcategory | null>(null);
  const [thumbnailFile, setThumbnailFile] = useState<File | null>(null);
  const [bannerFile, setbannerFile] = useState<File | null>(null);

  // Fetch all subcategories
  const { data: subcategories } = useQuery<Subcategory[]>({
    queryKey: ["/api/subcategories"],
    queryFn: () => apiRequest("GET", "/api/subcategories").then(res => res.json()),
  });

  // Fetch all categories for parent selection
  const { data: categories } = useQuery<Category[]>({
    queryKey: ["/api/categories"],
    queryFn: () => apiRequest("GET", "/api/categories").then(res => res.json()),
  });

  // Filter subcategories based on active tab and selected parent category
  const filteredSubcategories = subcategories?.filter(subcategory => {
    // Filter by type if not "all"
    const typeMatch = activeTab === "all" || subcategory.type === activeTab;
    
    // Filter by parent category if one is selected
    const parentMatch = selectedParentCategory === "all" || 
      subcategory.parentCategoryId.toString() === selectedParentCategory;
    
    return typeMatch && parentMatch;
  });
  
  // Form for adding a new subcategory
  const addForm = useForm<SubcategoryFormValues>({
    resolver: zodResolver(SubcategoryFormSchema),
    defaultValues: {
      name: "",
      type: "movie",
      parentCategoryId: 0,
      description: "",
      thumbnail: null,
      banner: null,
      isActive: true,
      displayOrder: 0,
    },
  });

  // Form for editing an existing subcategory
  const editForm = useForm<SubcategoryFormValues>({
    resolver: zodResolver(SubcategoryFormSchema),
    defaultValues: {
      name: "",
      type: "movie",
      parentCategoryId: 0,
      description: "",
      thumbnail: null,
      banner: null,
      isActive: true,
      displayOrder: 0,
    },
  });

  // Reset the edit form when a subcategory is selected for editing
  const initEditForm = (subcategory: Subcategory) => {
    editForm.reset({
      name: subcategory.name,
      type: subcategory.type,
      parentCategoryId: subcategory.parentCategoryId,
      description: subcategory.description,
      thumbnail: subcategory.thumbnail,
      banner: subcategory.banner,
      isActive: subcategory.isActive,
      displayOrder: subcategory.displayOrder,
    });
    setSelectedSubcategory(subcategory);
    setIsEditDialogOpen(true);
  };

  // Mutation for adding a new subcategory
  const createSubcategoryMutation = useMutation({
    mutationFn: async (data: InsertSubcategory) => {
      const response = await apiRequest("POST", "/api/subcategories", data);
      return response.json();
    },
    onSuccess: () => {
      queryClient.invalidateQueries({ queryKey: ["/api/subcategories"] });
      setIsAddDialogOpen(false);
      addForm.reset();
      toast({
        title: "Success",
        description: "Subcategory added successfully.",
      });
    },
    onError: (error: Error) => {
      toast({
        title: "Error",
        description: `Failed to add subcategory: ${error.message}`,
        variant: "destructive",
      });
    },
  });

  // Mutation for updating an existing subcategory
  const updateSubcategoryMutation = useMutation({
    mutationFn: async ({ id, data }: { id: number; data: Partial<InsertSubcategory> }) => {
      const response = await apiRequest("PATCH", `/api/subcategories/${id}`, data);
      return response.json();
    },
    onSuccess: () => {
      queryClient.invalidateQueries({ queryKey: ["/api/subcategories"] });
      setIsEditDialogOpen(false);
      setSelectedSubcategory(null);
      toast({
        title: "Success",
        description: "Subcategory updated successfully.",
      });
    },
    onError: (error: Error) => {
      toast({
        title: "Error",
        description: `Failed to update subcategory: ${error.message}`,
        variant: "destructive",
      });
    },
  });

  // Mutation for deleting a subcategory
  const deleteSubcategoryMutation = useMutation({
    mutationFn: async (id: number) => {
      await apiRequest("DELETE", `/api/subcategories/${id}`);
    },
    onSuccess: () => {
      queryClient.invalidateQueries({ queryKey: ["/api/subcategories"] });
      setIsDeleteDialogOpen(false);
      setSelectedSubcategory(null);
      toast({
        title: "Success",
        description: "Subcategory deleted successfully.",
      });
    },
    onError: (error: Error) => {
      toast({
        title: "Error",
        description: `Failed to delete subcategory: ${error.message}`,
        variant: "destructive",
      });
    },
  });

  // Handle subcategory deletion
  const handleDeleteSubcategory = (subcategory: Subcategory) => {
    setSelectedSubcategory(subcategory);
    setIsDeleteDialogOpen(true);
  };

  // Handle form submission for adding a new subcategory
  const onAddSubmit = (values: SubcategoryFormValues) => {
    // TODO: Handle file uploads for thumbnail and banner in a production app
    // For now, we're just using the values directly
    createSubcategoryMutation.mutate({
      ...values,
      thumbnail: values.thumbnail || null,
      banner: values.banner || null,
      displayOrder: values.displayOrder || 0,
    });
  };

  // Handle form submission for editing a subcategory
  const onEditSubmit = (values: SubcategoryFormValues) => {
    if (!selectedSubcategory) return;
    
    // TODO: Handle file uploads for thumbnail and banner in a production app
    // For now, we're just using the values directly
    updateSubcategoryMutation.mutate({
      id: selectedSubcategory.id,
      data: {
        ...values,
        thumbnail: values.thumbnail || null,
        banner: values.banner || null,
        displayOrder: values.displayOrder || 0,
      },
    });
  };

  // Get category name by ID
  const getCategoryName = (categoryId: number) => {
    const category = categories?.find(cat => cat.id === categoryId);
    return category ? category.name : "Unknown";
  };

  return (
    <DashboardLayout title="Subcategories" subtitle="Manage subcategories for different content types">
      <div className="mb-6 flex justify-between items-center">
        <div className="flex space-x-2">
          <Tabs value={activeTab} onValueChange={setActiveTab} className="w-full">
            <TabsList>
              <TabsTrigger value="all">All Types</TabsTrigger>
              <TabsTrigger value="movie">Movies</TabsTrigger>
              <TabsTrigger value="series">Series</TabsTrigger>
              <TabsTrigger value="channel">Channels</TabsTrigger>
              <TabsTrigger value="match">Matches</TabsTrigger>
            </TabsList>
          </Tabs>
          
          <Select 
            value={selectedParentCategory || ""} 
            onValueChange={setSelectedParentCategory}
          >
            <SelectTrigger className="w-[200px]">
              <SelectValue placeholder="Filter by Category" />
            </SelectTrigger>
            <SelectContent>
              <SelectItem value="all">All Categories</SelectItem>
              {categories?.map(category => (
                <SelectItem key={category.id} value={category.id.toString()}>
                  {category.name}
                </SelectItem>
              ))}
            </SelectContent>
          </Select>
        </div>
        
        <Dialog open={isAddDialogOpen} onOpenChange={setIsAddDialogOpen}>
          <DialogTrigger asChild>
            <Button>
              <FolderPlus className="mr-2 h-4 w-4" /> Add Subcategory
            </Button>
          </DialogTrigger>
          <DialogContent className="sm:max-w-[500px]">
            <DialogHeader>
              <DialogTitle>Add New Subcategory</DialogTitle>
            </DialogHeader>
            <Form {...addForm}>
              <form onSubmit={addForm.handleSubmit(onAddSubmit)} className="space-y-4">
                <FormField
                  control={addForm.control}
                  name="name"
                  render={({ field }) => (
                    <FormItem>
                      <FormLabel>Name</FormLabel>
                      <FormControl>
                        <Input placeholder="Enter subcategory name" {...field} />
                      </FormControl>
                      <FormMessage />
                    </FormItem>
                  )}
                />
                
                <div className="grid grid-cols-2 gap-4">
                  <FormField
                    control={addForm.control}
                    name="type"
                    render={({ field }) => (
                      <FormItem>
                        <FormLabel>Type</FormLabel>
                        <Select
                          value={field.value}
                          onValueChange={field.onChange}
                        >
                          <FormControl>
                            <SelectTrigger>
                              <SelectValue placeholder="Select content type" />
                            </SelectTrigger>
                          </FormControl>
                          <SelectContent>
                            <SelectItem value="movie">Movie</SelectItem>
                            <SelectItem value="series">Series</SelectItem>
                            <SelectItem value="channel">Channel</SelectItem>
                            <SelectItem value="match">Match</SelectItem>
                          </SelectContent>
                        </Select>
                        <FormMessage />
                      </FormItem>
                    )}
                  />
                  
                  <FormField
                    control={addForm.control}
                    name="parentCategoryId"
                    render={({ field }) => (
                      <FormItem>
                        <FormLabel>Parent Category</FormLabel>
                        <Select
                          value={field.value.toString()}
                          onValueChange={(value) => field.onChange(parseInt(value))}
                        >
                          <FormControl>
                            <SelectTrigger>
                              <SelectValue placeholder="Select parent category" />
                            </SelectTrigger>
                          </FormControl>
                          <SelectContent>
                            {categories?.filter(cat => cat.type === addForm.watch("type")).map(category => (
                              <SelectItem key={category.id} value={category.id.toString()}>
                                {category.name}
                              </SelectItem>
                            ))}
                          </SelectContent>
                        </Select>
                        <FormMessage />
                      </FormItem>
                    )}
                  />
                </div>
                
                <FormField
                  control={addForm.control}
                  name="description"
                  render={({ field }) => (
                    <FormItem>
                      <FormLabel>Description</FormLabel>
                      <FormControl>
                        <Textarea 
                          placeholder="Enter subcategory description" 
                          className="resize-none" 
                          {...field} 
                          value={field.value || ""}
                        />
                      </FormControl>
                      <FormMessage />
                    </FormItem>
                  )}
                />
                
                <div className="grid grid-cols-2 gap-4">
                  <FormField
                    control={addForm.control}
                    name="thumbnail"
                    render={({ field }) => (
                      <FormItem>
                        <FormLabel>Thumbnail URL</FormLabel>
                        <FormControl>
                          <Input 
                            placeholder="Enter thumbnail URL" 
                            {...field} 
                            value={field.value || ""}
                          />
                        </FormControl>
                        <FormMessage />
                      </FormItem>
                    )}
                  />
                  
                  <FormField
                    control={addForm.control}
                    name="banner"
                    render={({ field }) => (
                      <FormItem>
                        <FormLabel>Banner URL</FormLabel>
                        <FormControl>
                          <Input 
                            placeholder="Enter banner URL" 
                            {...field} 
                            value={field.value || ""}
                          />
                        </FormControl>
                        <FormMessage />
                      </FormItem>
                    )}
                  />
                </div>
                
                <div className="grid grid-cols-2 gap-4">
                  <FormField
                    control={addForm.control}
                    name="isActive"
                    render={({ field }) => (
                      <FormItem className="flex flex-row items-center justify-between space-y-0 rounded-lg border p-3">
                        <FormLabel>Active</FormLabel>
                        <FormControl>
                          <Switch
                            checked={field.value}
                            onCheckedChange={field.onChange}
                          />
                        </FormControl>
                      </FormItem>
                    )}
                  />
                  
                  <FormField
                    control={addForm.control}
                    name="displayOrder"
                    render={({ field }) => (
                      <FormItem>
                        <FormLabel>Display Order</FormLabel>
                        <FormControl>
                          <Input 
                            type="number" 
                            placeholder="Display order" 
                            {...field} 
                            value={field.value === null ? "" : field.value}
                          />
                        </FormControl>
                        <FormMessage />
                      </FormItem>
                    )}
                  />
                </div>
                
                <DialogFooter>
                  <Button variant="outline" type="button" onClick={() => setIsAddDialogOpen(false)}>
                    Cancel
                  </Button>
                  <Button type="submit" disabled={createSubcategoryMutation.isPending}>
                    {createSubcategoryMutation.isPending ? "Adding..." : "Add Subcategory"}
                  </Button>
                </DialogFooter>
              </form>
            </Form>
          </DialogContent>
        </Dialog>
      </div>

      {/* Edit Dialog */}
      <Dialog open={isEditDialogOpen} onOpenChange={setIsEditDialogOpen}>
        <DialogContent className="sm:max-w-[500px]">
          <DialogHeader>
            <DialogTitle>Edit Subcategory</DialogTitle>
          </DialogHeader>
          <Form {...editForm}>
            <form onSubmit={editForm.handleSubmit(onEditSubmit)} className="space-y-4">
              <FormField
                control={editForm.control}
                name="name"
                render={({ field }) => (
                  <FormItem>
                    <FormLabel>Name</FormLabel>
                    <FormControl>
                      <Input placeholder="Enter subcategory name" {...field} />
                    </FormControl>
                    <FormMessage />
                  </FormItem>
                )}
              />
              
              <div className="grid grid-cols-2 gap-4">
                <FormField
                  control={editForm.control}
                  name="type"
                  render={({ field }) => (
                    <FormItem>
                      <FormLabel>Type</FormLabel>
                      <Select
                        value={field.value}
                        onValueChange={field.onChange}
                      >
                        <FormControl>
                          <SelectTrigger>
                            <SelectValue placeholder="Select content type" />
                          </SelectTrigger>
                        </FormControl>
                        <SelectContent>
                          <SelectItem value="movie">Movie</SelectItem>
                          <SelectItem value="series">Series</SelectItem>
                          <SelectItem value="channel">Channel</SelectItem>
                          <SelectItem value="match">Match</SelectItem>
                        </SelectContent>
                      </Select>
                      <FormMessage />
                    </FormItem>
                  )}
                />
                
                <FormField
                  control={editForm.control}
                  name="parentCategoryId"
                  render={({ field }) => (
                    <FormItem>
                      <FormLabel>Parent Category</FormLabel>
                      <Select
                        value={field.value.toString()}
                        onValueChange={(value) => field.onChange(parseInt(value))}
                      >
                        <FormControl>
                          <SelectTrigger>
                            <SelectValue placeholder="Select parent category" />
                          </SelectTrigger>
                        </FormControl>
                        <SelectContent>
                          {categories?.filter(cat => cat.type === editForm.watch("type")).map(category => (
                            <SelectItem key={category.id} value={category.id.toString()}>
                              {category.name}
                            </SelectItem>
                          ))}
                        </SelectContent>
                      </Select>
                      <FormMessage />
                    </FormItem>
                  )}
                />
              </div>
              
              <FormField
                control={editForm.control}
                name="description"
                render={({ field }) => (
                  <FormItem>
                    <FormLabel>Description</FormLabel>
                    <FormControl>
                      <Textarea 
                        placeholder="Enter subcategory description" 
                        className="resize-none" 
                        {...field} 
                        value={field.value || ""}
                      />
                    </FormControl>
                    <FormMessage />
                  </FormItem>
                )}
              />
              
              <div className="grid grid-cols-2 gap-4">
                <FormField
                  control={editForm.control}
                  name="thumbnail"
                  render={({ field }) => (
                    <FormItem>
                      <FormLabel>Thumbnail URL</FormLabel>
                      <FormControl>
                        <Input 
                          placeholder="Enter thumbnail URL" 
                          {...field} 
                          value={field.value || ""}
                        />
                      </FormControl>
                      <FormMessage />
                    </FormItem>
                  )}
                />
                
                <FormField
                  control={editForm.control}
                  name="banner"
                  render={({ field }) => (
                    <FormItem>
                      <FormLabel>Banner URL</FormLabel>
                      <FormControl>
                        <Input 
                          placeholder="Enter banner URL" 
                          {...field} 
                          value={field.value || ""}
                        />
                      </FormControl>
                      <FormMessage />
                    </FormItem>
                  )}
                />
              </div>
              
              <div className="grid grid-cols-2 gap-4">
                <FormField
                  control={editForm.control}
                  name="isActive"
                  render={({ field }) => (
                    <FormItem className="flex flex-row items-center justify-between space-y-0 rounded-lg border p-3">
                      <FormLabel>Active</FormLabel>
                      <FormControl>
                        <Switch
                          checked={field.value}
                          onCheckedChange={field.onChange}
                        />
                      </FormControl>
                    </FormItem>
                  )}
                />
                
                <FormField
                  control={editForm.control}
                  name="displayOrder"
                  render={({ field }) => (
                    <FormItem>
                      <FormLabel>Display Order</FormLabel>
                      <FormControl>
                        <Input 
                          type="number" 
                          placeholder="Display order" 
                          {...field} 
                          value={field.value === null ? "" : field.value}
                        />
                      </FormControl>
                      <FormMessage />
                    </FormItem>
                  )}
                />
              </div>
              
              <DialogFooter>
                <Button variant="outline" type="button" onClick={() => setIsEditDialogOpen(false)}>
                  Cancel
                </Button>
                <Button type="submit" disabled={updateSubcategoryMutation.isPending}>
                  {updateSubcategoryMutation.isPending ? "Updating..." : "Update Subcategory"}
                </Button>
              </DialogFooter>
            </form>
          </Form>
        </DialogContent>
      </Dialog>

      {/* Delete Confirmation Dialog */}
      <Dialog open={isDeleteDialogOpen} onOpenChange={setIsDeleteDialogOpen}>
        <DialogContent className="sm:max-w-[425px]">
          <DialogHeader>
            <DialogTitle>Confirm Deletion</DialogTitle>
          </DialogHeader>
          <div className="py-4">
            Are you sure you want to delete the subcategory "{selectedSubcategory?.name}"? This action cannot be undone.
          </div>
          <DialogFooter>
            <Button variant="outline" onClick={() => setIsDeleteDialogOpen(false)}>
              Cancel
            </Button>
            <Button 
              variant="destructive" 
              onClick={() => selectedSubcategory && deleteSubcategoryMutation.mutate(selectedSubcategory.id)}
              disabled={deleteSubcategoryMutation.isPending}
            >
              {deleteSubcategoryMutation.isPending ? "Deleting..." : "Delete Subcategory"}
            </Button>
          </DialogFooter>
        </DialogContent>
      </Dialog>

      {/* Subcategories Grid */}
      <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-4">
        {filteredSubcategories?.map((subcategory) => (
          <Card key={subcategory.id} className="overflow-hidden">
            {subcategory.banner && (
              <div className="h-32 w-full overflow-hidden">
                <img 
                  src={subcategory.banner} 
                  alt={subcategory.name} 
                  className="w-full h-full object-cover"
                />
              </div>
            )}
            <CardHeader className="flex flex-row items-center justify-between space-y-0 pb-2">
              <CardTitle className="text-lg font-medium">
                {subcategory.name}
                {!subcategory.isActive && <span className="ml-2 text-xs bg-amber-100 text-amber-800 rounded-full px-2 py-1">Inactive</span>}
              </CardTitle>
              <div className="flex space-x-1">
                <Button variant="ghost" size="icon" onClick={() => initEditForm(subcategory)}>
                  <Edit className="h-4 w-4" />
                </Button>
                <Button variant="ghost" size="icon" onClick={() => handleDeleteSubcategory(subcategory)}>
                  <Trash2 className="h-4 w-4" />
                </Button>
              </div>
            </CardHeader>
            <CardContent>
              <div className="grid grid-cols-2 gap-2 text-sm mb-3">
                <div className="font-semibold">Type:</div>
                <div className="capitalize">{subcategory.type}</div>
                
                <div className="font-semibold">Parent Category:</div>
                <div>{getCategoryName(subcategory.parentCategoryId)}</div>
                
                <div className="font-semibold">Display Order:</div>
                <div>{subcategory.displayOrder ?? "Not set"}</div>
              </div>
              
              {subcategory.description && (
                <p className="text-sm text-muted-foreground line-clamp-2">{subcategory.description}</p>
              )}
              
              {subcategory.thumbnail && (
                <div className="mt-3 flex justify-center">
                  <img 
                    src={subcategory.thumbnail} 
                    alt={`${subcategory.name} thumbnail`} 
                    className="h-16 w-16 object-cover rounded-md"
                  />
                </div>
              )}
            </CardContent>
          </Card>
        ))}
        
        {/* Empty state */}
        {filteredSubcategories?.length === 0 && (
          <div className="col-span-full flex flex-col items-center justify-center py-12 text-center">
            <Filter className="h-12 w-12 text-muted-foreground mb-4" />
            <h3 className="text-lg font-medium">No subcategories found</h3>
            <p className="text-sm text-muted-foreground mt-1">
              {activeTab !== "all" 
                ? `No subcategories with type "${activeTab}" found.` 
                : selectedParentCategory !== "all" 
                  ? "No subcategories found for the selected parent category." 
                  : "No subcategories have been created yet."}
            </p>
            <Button onClick={() => setIsAddDialogOpen(true)} className="mt-4">
              <FolderPlus className="mr-2 h-4 w-4" /> Add Subcategory
            </Button>
          </div>
        )}
      </div>
    </DashboardLayout>
  );
}